@@ -6,7 +6,7 @@ from hgboost.hgboost import (
 
 __author__ = 'Erdogan Tasksen'
 __email__ = 'erdogant@gmail.com'
-__version__ = '0.1.4'
+__version__ = '0.1.5'
 
 # module level doc-string
 __doc__ = """
@@ -95,5 +95,7 @@ Example
 References
 ----------
 * https://github.com/erdogant/hgboost
-
+* https://erdogant.github.io/hgboost/
+* https://colab.research.google.com/github/erdogant/hgboost/blob/master/notebooks/hgboost_classification_examples.ipynb
+* https://colab.research.google.com/github/erdogant/hgboost/blob/master/notebooks/hgboost_regression_examples.ipynb
 """
